==> mcp_server_hatena_weekly-0.1.1.tar.gz: mcp_server_hatena_weekly-0.1.1/README.md <==
# Hatena Bookmark Weekly/Monthly Ranking MCP Server

An MCP server that provides Hatena Bookmark weekly and monthly ranking data. Contains data from January to May 2025.

## 🛠️ Available Tools

### `weekly` - Weekly Ranking Retrieval

**Description**: Retrieve weekly Hatena bookmark rankings (30 entries) for a specified week

**Parameters**:

- `year` (integer, required): Year (2025 only)
- `month` (integer, required): Month (1-5)
- `week` (integer, required): Week number (1-5, week 5 only exists in March)

### `monthly` - Monthly Ranking Retrieval

**Description**: Retrieve monthly Hatena bookmark rankings (50 entries) for a specified month

**Parameters**:

- `year` (integer, required): Year (2025 only)
- `month` (integer, required): Month (1-5)

## Installation

### Using `uv` (Recommended)

No special installation is required when using `uv`. You can run `mcp-server-hatena-weekly` directly using `uvx`.

### Using PIP

Alternatively, you can install `mcp-server-hatena-weekly` using pip:

```sh
pip install mcp-server-hatena-weekly
```

After installation, you can run the script as follows:

```sh
mcp-server-hatena-weekly
```

## Configuration

### Configure for Claude.app

Add to your Claude settings:

<details>
<summary>Using uvx</summary>

```json
{
  "mcpServers": {
    "hatena-weekly": {
      "command": "uvx",
      "args": ["mcp-server-hatena-weekly"]
    }
  }
}
```

</details>

### Configure for VS Code

For quick installation, use one of the one-click install buttons below...

[![Install with UV in VS Code](https://img.shields.io/badge/VS_Code-UV-0098FF?style=flat-square&logo=visualstudiocode&logoColor=white)](https://insiders.vscode.dev/redirect/mcp/install?name=hatena-weekly&config=%7B%22command%22%3A%22uvx%22%2C%22args%22%3A%5B%22mcp-server-hatena-weekly%22%5D%7D)

### Command Line Options

You can specify the following options when running the server:

- `--sse`: Enable Server-Sent Events transport (on/off)
- `--host`: Server bind address (default: localhost)
- `--port`: Server port number (default: 8000)
- `--log-level`: Logging verbosity (debug, info, warning, error)

## 📄 License

MIT License

==> mcp_server_hatena_weekly-0.1.3.tar.gz: mcp_server_hatena_weekly-0.1.3/README.md <==
# Hatena Bookmark Weekly/Monthly Ranking MCP Server

An MCP server that provides Hatena Bookmark weekly and monthly ranking data. Contains data from January to June 2025 (weekly data available for weeks 1-2 of June, monthly data through May).

## 🛠️ Available Tools

### `weekly` - Weekly Ranking Retrieval

**Description**: Retrieve weekly Hatena bookmark rankings (30 entries) for a specified week

**Parameters**:

- `year` (integer, required): Year (2025 only)
- `month` (integer, required): Month (1-6)
- `week` (integer, required): Week number (1-5, week 5 only exists in some months)

### `monthly` - Monthly Ranking Retrieval

**Description**: Retrieve monthly Hatena bookmark rankings (50 entries) for a specified month

**Parameters**:

- `year` (integer, required): Year (2025 only)
- `month` (integer, required): Month (1-5, June data will be available after month end)

## Installation

### Using `uv` (Recommended)

No special installation is required when using `uv`. You can run `mcp-server-hatena-weekly` directly using `uvx`.

### Using PIP

Alternatively, you can install `mcp-server-hatena-weekly` using pip:

```sh
pip install mcp-server-hatena-weekly
```

After installation, you can run the script as follows:

```sh
mcp-server-hatena-weekly
```

## Configuration

### Configure for Claude.app

Add to your Claude settings:

<details>
<summary>Using uvx</summary>

```json
{
  "mcpServers": {
    "hatena-weekly": {
      "command": "uvx",
      "args": ["mcp-server-hatena-weekly"]
    }
  }
}
```

</details>

### Configure for VS Code

For quick installation, use one of the one-click install buttons below...

[![Install with UV in VS Code](https://img.shields.io/badge/VS_Code-UV-0098FF?style=flat-square&logo=visualstudiocode&logoColor=white)](https://insiders.vscode.dev/redirect/mcp/install?name=hatena-weekly&config=%7B%22command%22%3A%22uvx%22%2C%22args%22%3A%5B%22mcp-server-hatena-weekly%22%5D%7D)

### Command Line Options

You can specify the following options when running the server:

- `--sse`: Enable Server-Sent Events transport (on/off)
- `--host`: Server bind address (default: localhost)
- `--port`: Server port number (default: 8000)
- `--log-level`: Logging verbosity (debug, info, warning, error)

## 📄 License

MIT License
